<?php

declare(strict_types = 1);

namespace Drupal\brightcove_gallery\Services;

use Drupal\brightcove\Services\SettingsBase;
use Drupal\brightcove_gallery\Services\Exception\SettingsInvalidArgumentException;

/**
 * Sub-settings handler for In-Page Experience.
 */
final class InPageExperienceSettings extends SettingsBase implements InPageExperienceSettingsInterface {

  /**
   * Settings storage name.
   */
  public const STORAGE = Settings::STORAGE;

  /**
   * Base name of the sub-settings.
   */
  public const SUB_SETTINGS = 'in_page_experience';

  /**
   * Setting for the cache seconds.
   */
  public const CACHE_SECONDS = self::SUB_SETTINGS . '.cache_seconds';

  /**
   * {@inheritdoc}
   */
  public function getCacheSeconds(): int {
    return $this->configFactory->get(static::STORAGE)->get(static::CACHE_SECONDS) ?? -1;
  }

  /**
   * {@inheritdoc}
   */
  public function setCacheSeconds(int $seconds): void {
    if ($seconds < -1) {
      throw new SettingsInvalidArgumentException('The given seconds cannot be lower than -1.');
    }
    $this->set(static::CACHE_SECONDS, $seconds);
  }

}
